#ifndef NT2_INCLUDE_CONSTANTS_THOUSAND_HPP_INCLUDED
#define NT2_INCLUDE_CONSTANTS_THOUSAND_HPP_INCLUDED

#include <nt2/constant/include/constants/thousand.hpp>

#endif
